#!/tmp/.ZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZpErLZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZperl/bin/perl -w

use strict;
use Carp;
use PureMessage::Manager::Request qw($REQUEST %in %text);
use PureMessage::Reports::Report;
use PureMessage::Manager::Response::Reports;
use PureMessage::Logger;

###############################################################################
# Set up a logger.
###############################################################################
my $log = PureMessage::Logger->new( 'ident' => 'reports_chart' );

###############################################################################
# Flag export to file option, if requested
###############################################################################
my $export_to_file = (exists($in{'export'}) and $in{'export'} == 1) ? 1 : 0;
delete $in{'export'};

###############################################################################
# Get the response object only if we need to export report to a csv file
###############################################################################
my $response = undef;

if ($export_to_file) {
    $response = $REQUEST->get_response(
        'PureMessage::Manager::Response::Reports',
        'content-type' => 'text/csv',
        'http-headers' => {
            'Content-Description' => 'export.csv',
            'Content-Disposition' => 'attachment; filename="export.csv"',
                          },
        'stderr_to_stdout' => 1,
                                         );
    exit unless $response;
}

###############################################################################
# Generate the report chart.  Wrapped in an eval block for easier error
# handling.
###############################################################################
eval
{
    ###########################################################################
    # Create the report object.
    ###########################################################################
    my $rid = $in{'id'};
    my $report = new PureMessage::Reports::Report( $rid );

    ###########################################################################
    # Run the report and get the resulting image.
    ###########################################################################
    my $report_output = $report->run_report( %in );
    die "Failed to create the GD image.\n" if (not $report_output);
    my $mtype;
    $mtype = $report->mime_type() if (not $export_to_file);

    ###########################################################################
    # Spit out the chart.
    ###########################################################################
    print "Content-Type: $mtype\n\n" if (not $export_to_file);
    print $report_output;
};

if ($@)
{
    print "Content-Type: text/plain\n\n" if (not $export_to_file);
    print "Error: $@\n";
    $log->log( 'DEBUG', "Chart Error: $@" );
}
