package PureMessage::Manager::Response::DashBars::Reports;

###############################################################################
# Required inclusions
###############################################################################
use strict;
use PureMessage::Reports::Report;
use PureMessage::Manager::Response::Reports::Utils qw(_mk_html_chart _mk_query_string REPORTS_CGI);

###############################################################################
# Default values.
###############################################################################
my %defaults = (
    'history'   => '12h',
    'height'    => 200,
    'width'     => 200,
    );

###############################################################################
# Returns the HTML required to show the report in the dashbar.
#
# The following arguments can be set to alter the display of the report:
#
#   Value       Default             Description
#   id          msgcategories       report ID to show
#   format      bars                chart format
#   ... and any of the report running options (PM::Reports::Report::run_report)
#
# the args must be listed in key value pairs
#   e.g. "id spamranges format tbl height 200 width 300 history 7d"
###############################################################################
sub Show {
    my ($widget, %args) = @_;

    ###########################################################################
    # Use defaults where other values not provided.
    ###########################################################################
    map { $args{$_} = $defaults{$_} if (!defined $args{$_}) } keys %defaults;

    ###########################################################################
    # Figure out which report we're showing, and get a report object.
    ###########################################################################
    my $report = new PureMessage::Reports::Report( $args{'id'} );

    ###########################################################################
    # Based on the requested format, either generate the HTML for the report
    # table, -or- generate HTML to graph the report.
    ###########################################################################
    if ($args{'format'} eq 'tbl') {
        # TABLE; generate HTML to show the report inline
        $args{'more_href'} = REPORTS_CGI . '?' . _mk_query_string( %args, 'v' => 'report' );
        return $report->run_report( %args );
    }
    else {
        # GRAPH; generate HTML to graph the report.
        return _mk_html_chart( $report, %args, 'showlegend' => 1 );
    }
}

1;
