package PureMessage::Reports::Config;
use strict;
use warnings;

use Carp;
use PureMessage::Config qw(expand_filename);
use ActiveState::Config;
use PureMessage::Reports::Config::DB;

# This module encapsulates access to the PMX reporting configuration
# data. Note that it does not inherit from ActiveState::Config (as
# PureMessage...Config.pm modules commonly do), since it does not necessarily
# operate on configuration file, and the configuration file does not
# necessarily need to be available on all the hosts on which this module
# gets initialized.

sub new {
    my $class = shift;
    my $self = {};
    $self->{cfg_db} = PureMessage::Reports::Config::DB->new();
    bless($self, $class);
    return $self;
}

# replaces the current reports config data with data from the config file
sub prd_cfg_refresh {
    my $self = shift;
    my $cfg_as_hash = $self->_prd_cfg_get_hash();
    $self->{cfg_db}->prd_cfg_db_delete();
    $self->{cfg_db}->prd_cfg_db_store($cfg_as_hash);
    print "Reporting configuration data updated from configuration file.\n";
}

# replaces the current reports config data with hard-coded defaults
sub prd_cfg_reset {
    my $self = shift;
    $self->{cfg_db}->prd_cfg_db_delete();
    $self->{cfg_db}->prd_cfg_db_store_defaults();
    print "Reporting configuration data reset to default values.\n";
}

# prints the contents of reports configuration db to the std output
# (formatted as configuration file)
sub prd_cfg_dump {
    my $self = shift;
    $self->{cfg_db}->prd_cfg_db_dump();
}

sub prd_cfg_fact_is_collected {
    my $self = shift;
    my $fact = shift;
    return $self->{cfg_db}->prd_cfg_db_fact_is_collected($fact);
}

sub prd_cfg_dim_is_collected {
    my $self = shift;
    my $fact = shift;
    my $dim = shift;
    return $self->{cfg_db}->prd_cfg_db_dim_is_collected($fact, $dim);
}

# returns a pair of (match, don't match) filtering patterns for the
# specified dimension
sub prd_cfg_dim_filters {
    my $self = shift;
    my $dim = shift;
    return $self->{cfg_db}->prd_cfg_db_dim_filters($dim);
}

# returns a structure with data reduction action information
sub prd_cfg_reduction_actions {
    #XXX implement this, eventually, an use in Reductor.pm
}

# returns the contents of configuration file as a hash structure
sub _prd_cfg_get_hash {
    my $self = shift;
    my %opt;
    my $cfg_file = expand_filename("etc/prd_database.conf");
    my $cfg = ActiveState::Config->new(allow_includes => 1);
    $cfg->parse_file($cfg_file, rotate => 9, %opt);
    return $cfg->as_hash();
}

1;
