package PureMessage::Reports::Consumer;
use strict;
use warnings;

my $ETL_PERIOD_MINS = 5;    # granularity of input (detail) periods.

sub new {
    my ($class, $dbh, %opts) = @_;
    my $self = { dbh => $dbh, 
                 items => {},
                 last_period => '',
                 %opts,
               };
    bless $self, $class;
    return $self;
}

sub add {
    my ($self, %opts) = @_;

    for my $f (@{$self->{mandatory_opts}}) {
        die "Field $f is not defined!" unless exists $opts{$f};

        # Remove any tabs
        if (ref($opts{$f})) {
            if (ref($opts{$f}) eq 'ARRAY') {
                map { s/\t//g if $_ } @{$opts{$f}};
            }
            else {
                map { s/\t//g if $_ } values %{$opts{$f}};
            }
        }
        else {
            $opts{$f} =~ s/\t//g if $opts{$f};
        }
    }

    my $groups = $opts{groups};
    $groups = [$groups] unless ref($groups) eq 'ARRAY';
    $groups = ['__NO_GROUP__', map {(split '\|', $_ || '')[1]} @$groups];
    my %g_hash = map {$_ => 1} @$groups;
    $groups = [keys %g_hash];
    $opts{groups} = $groups;

    { # Round down to a multiple of 5 mins.
        my $timestamp = delete $opts{timestamp};
        my ($date,$hour,$min) = $timestamp =~ /(\d+-\d+-\d+)[ T](\d+):(\d+)/;
        $min -= $min % $ETL_PERIOD_MINS;        
        $opts{period_start} = sprintf "${date} %02.2d:%02.2d", $hour, $min;

        # auto-flush when the period changes
        $self->{last_period} ||= $opts{period_start};
        if ($self->{last_period} lt $opts{period_start}) {
            $self->_flush;
            $self->{last_period} = $opts{period_start};
        }
    }

    # Convert inbound flag to true/false
    if (exists $opts{inbound}) {
        $opts{inbound} = $opts{inbound} ? 'true' : 'false';
    }

    $self->_add(%opts);
}

sub _add { die "Subclass must provide this!" }

sub _flush {
    my ($self) = @_;
    return unless keys %{$self->{items}};

    my $dbh = $self->{dbh};
    $dbh->do("COPY prd_$self->{fact} FROM stdin");
    for my $i (sort keys %{$self->{items}}) {
        my $line = join("\t", $i, delete $self->{items}{$i}) . "\n";
        $dbh->func($line, 'putline');
    }
    $dbh->func('endcopy');
}

1;
