package PureMessage::Reports::DB;

use strict;
use warnings;
use Carp;
use DBI;
use base qw(Exporter);
use PureMessage::Database::Config;
use PureMessage::Config qw(%config);

our @EXPORT = qw(get_dbh get_dsn get_dbname);

sub get_dsn {
    my $reports_data_store = $config{'pmx_prd_store'} || 'pmx_quarantine';
    my $db_config = PureMessage::Database::Config->new();
    my $dsn = $db_config->store_value($reports_data_store, "dsn") || $ENV{'PMX_DBI_SOURCE'};
    return $dsn;
}

sub get_dbh {
    my $dsn = shift || get_dsn();

    # NOTE: We ensure that all database handles open using exactly the same
    # connection arguments so that DBI handles can be shared among multiple
    # packages.  See the following docs for more details.
    # http://perl.apache.org/docs/1.0/guide/databases.html#Opening_Connections_With_Different_Parameters
    my $connect_method = $ENV{MOD_PERL} ? "connect" : "connect_cached";
    my $dbh = DBI->$connect_method($dsn, "", "", {RaiseError  => 0, 
                                                  PrintError  => 0, 
                                                  AutoCommit  => 0,
                                                 }) 
            or croak ("Could not connect to database with dsn \"$dsn\": $!");
    $dbh->{RaiseError}  = 0; 
    $dbh->{PrintError}  = 0; 
    $dbh->{AutoCommit}  = 0; 
    $dbh->{HandleError} = undef;
    return $dbh;
}

sub get_dbname {
    my $dsn = shift || get_dsn();
    return $1 if $dsn =~ /dbname=(\w+)/;
    return;
}

1;
