package PureMessage::Reports::Report::Config;
use strict;
use PureMessage::Config qw(expand_filename);
use ActiveState::Config;
use PureMessage::Version qw($PREFIX);
use PureMessage::Reports::Report::Config::Validator;
use base qw(Exporter);

our @EXPORT_OK = qw(
    %config
    $object
    %reports_config
    list_report_ids
    get_report_info
    );
our %config;

our $reports_config;    # alias that doesn't clash with other %configs
*reports_config= \%config;

our $object;

sub refresh () {

    my $object = ActiveState::Config->new(strict => 1);
    
    PureMessage::Reports::Report::Config::Validator->validate($object);
    $object->parse_file("$PREFIX/etc/reports.conf");
    %config = $object->as_hash();
    \%config;   # return this so the refresher can get it
}

refresh();

=item edit()

  Will open this config as a writeable ActiveState::Config object
  and return it.  This can die when configuration file has invalid
  syntax.

=cut

sub edit {
    my $p = ActiveState::Config->new(strict => 1);
    
    PureMessage::Reports::Report::Config::Validator->validate($object);
    $p->parse_file("$PREFIX/etc/reports.conf",writable => 1);
 
    PureMessage::Reports::Report::Config::Validator->validate($p);
    $p->parse_file();       # the resource knows where the file is
    return $p
}

=item list_report_ids()

  Returns a sorted list of the known report ids.

=cut

sub list_report_ids
{
    return sort keys %{$config{'report'}};
}

=item get_report_info($rid)

  Returns a hash-ref of information on the specified report.

=cut

sub get_report_info
{
    my ($rid) = @_;
    return $config{'report'}{$rid};
}

1;
