package PureMessage::Reports::Report::Config::Validator;

###############################################################################
# Required inclusions.
###############################################################################
use base qw(PureMessage::Config::Validator Exporter);

###############################################################################
# Add validation rules/defaults to the config parser.
###############################################################################
sub validate {
    my ($pkg, $p) = @_;

    ###########################################################################
    # Define validation rules and default values.
    ###########################################################################
    my %conf = (
        'report#*.title'            => ['#str'],
        'report#*.desc'             => ['#str'],
        'report#*.nodata'           => ['#str'],
        'report#*.per_host'         => ['#num'],
        'report#*.format'           => ['#list #enum tbl lines bars bars_stacked', 'tbl'],
        'report#*.period_start'     => ['#num'],   # date/time as epoch offset
        'report#*.period_end'       => ['#num'],   # date/time as epoch offset
        'report#*.grouping'         => ['#enum minute hour day month year',],
        'report#*.pivot'            => ['#str'],
        'report#*.order.dimension'  => ['#str'],
        'report#*.labels.label'     => ['#str'],
        'report#*.fact#*.dimension' => ['#str'],
        'report#*.dimension#*.match_filter_pattern'         => ['#str'],
        'report#*.dimension#*.dont_match_filter_pattern'    => ['#str'],
        'report#*.data_pnt'         => ['#str'],
        'report#*.pivot_total'      => ['#num'],
        'report#*.sampling_period'  => ['#atom nodups', undef],
        );

    ###########################################################################
    # Add our validation rules to the parser.
    ###########################################################################
    foreach my $key (keys %conf)
    {
        my ($type, $def) = @{$conf{$key}};
        $p->typedecl( $key, $type ) if (defined $type);
        $p->default( $key, $def )   if (defined $def);
    }
}

1;
