package PureMessage::Reports::Report::Format;

###############################################################################
# Required inclusions.
###############################################################################
use strict;
use Carp;
use base qw(Exporter);
our @EXPORT_OK = qw(
    DCLRS
    );

###############################################################################
# Returns a list of colours used in report charts/legends.
# XXX better colour selection?
###############################################################################
sub DCLRS {
    ( '#375896',
      '#5E6164',
      '#A93344',
      '#999474',
      '#387E82',
      '#B9AEA2',
      '#7386B5',
      '#000000',
      '#7B797B',
      '#FF0000',
    );
}

###############################################################################
# Instantiates a report formatter, and returns it back to the caller.
###############################################################################
sub new
{
    my ($proto) = @_;
    my $class = ref($proto) || $proto;
    my $self = {};
    bless $self, $class;
    return $self;
}

###############################################################################
# Returns the list of colours used, as a list-ref.
###############################################################################
sub dclrs { [DCLRS] };

###############################################################################
# Returns the MIME-Type of the formatted report output.  This method MUST be
# implemented by all derived classes.
###############################################################################
sub mime_type
{
    my ($self) = @_;
    croak "Report format interface not fully implemented in " . ref($self);
}

###############################################################################
# Formats the provided report data based on the specified options, returning
# the formatted results back to the caller.  This method MUST be implemented by
# all derived classes.
#
# The following options are accepted:
#   limit           - max records to show in output
#   height          - height (in pixels)
#   width           - width (in pixels)
#   more_href       - href for link to click-through report
#   labels          - column/legend labels
#   legend          - actual legend to use, as HTML
#   colours         - list of colours for charts
###############################################################################
sub format
{
    my ($self, $results, %opts) = @_;
    croak "Report format interface not fully implemented in " . ref($self);
}

1;
