package PureMessage::Reports::Report::Format::csv;

###############################################################################
# Required inclusions.
###############################################################################
use strict;
use Text::CSV_XS;
use base qw(PureMessage::Reports::Report::Format);

###############################################################################
# Returns the MIME-Type of the formatted output.
###############################################################################
sub mime_type { return 'text/html' };

###############################################################################
# Formats the report data as CSV.
###############################################################################
sub format
{
    my ($self, $data, %opts) = @_;

    ###########################################################################
    # Create a CSV formatter, and start our string...
    ###########################################################################
    my $csv = new Text::CSV_XS;
    my $str = '';

    ###########################################################################
    # Column labels.
    ###########################################################################
    $csv->combine( @{$opts{'labels'}} );
    $str .= $csv->string() . "\n";

    ###########################################################################
    # Report data.
    ###########################################################################
    foreach my $row (@{$data})
    {
        $csv->combine( @{$row} );
        $str .= $csv->string() . "\n";
    }

    ###########################################################################
    # If we didn't get any data, make note of that.
    ###########################################################################
    if (scalar( @{$data} ) == 0)
    {
        $str .= "No data was found for this report in the selected time frame.";
    }

    ###########################################################################
    # Done; return string back to caller.
    ###########################################################################
    return $str;
}

1;
