package PureMessage::Reports::Report::Format::graphical;

###############################################################################
# Required inclusions.
###############################################################################
use strict;
use PureMessage::Reports::Report::Format::chart qw(%defaults);
use base qw(PureMessage::Reports::Report::Format::chart);

###############################################################################
# Pixel width to give each label
###############################################################################
our $x_label_width = 20;

###############################################################################
# Overloaded formatting method
#
#   Line, bar and stacked bar graphs are typically used to display data whose
#   X axis is linear; end users can "fill in the blanks" if a few labels are
#   missing, which is better than them bleeding together.  This makes sure we
#   have enough room for each label on our X axis.
###############################################################################
sub format {
    my($self, $data, %opts) = @_;

    my $width = $self->{'width'} || $opts{width} || $defaults{width};

    my $max_labels = int($width / $x_label_width);
    my $label_interval = scalar(@$data) / $max_labels;

    if($label_interval > 1) {
        $label_interval = int($label_interval) + 1;
        $opts{gdgraph}{x_label_skip} = $label_interval;
    }

    $self->SUPER::format($data, %opts);
}

1;
