package PureMessage::Reports::Util;

use strict;
use warnings;
use base qw(Exporter);
use Time::Local;
use Net::Domain qw(hostfqdn);

our @EXPORT_OK = qw(round_time_hour round_time_day round_time_month
                    get_hostname
                   );

sub round_time_hour {
    my $time = shift;
    if (! $time) {
	$time = time();
    }
    my ($sec, $min, $hour, $mday, $mon, $year, $wday, $yday, $isdst) = localtime($time);
    my $round_time = timelocal(0, 0, $hour, $mday, $mon, $year);
    return $round_time;
}

sub round_time_day {
    my $time = shift;
    if (! $time) {
	$time = time();
    }
    my ($sec, $min, $hour, $mday, $mon, $year, $wday, $yday, $isdst) = localtime($time);
    my $round_time = timelocal(0, 0, 0, $mday, $mon, $year);
    return $round_time;
}

sub round_time_month {
    my $time = shift;
    if (! $time) {
	$time = time();
    }
    my ($sec, $min, $hour, $mday, $mon, $year, $wday, $yday, $isdst) = localtime($time);
    my $round_time = timelocal(0, 0, 0, 1, $mon, $year);
    return $round_time;
}

sub get_hostname {
    my $dbh = shift;
    return unless $dbh;
    
    my $max_hostname_length = 128;
    my $hostname =  substr(lc(hostfqdn()), 0, $max_hostname_length);

    # data conversion from old hostaname (ex: bob) to new fqdn host name
    # (ex: bob.domain.com) happens every time this function is called.
    # ideally this should be a one time conversion and should be refactored
    # once supporting functionality to run one-time jobs will be built in PM.
    _convert_to_fqdn($dbh, $hostname);
    _save_hostname($dbh, $hostname);

    return $hostname;
}

sub _convert_to_fqdn {
    my ($dbh, $fqdn_host) = @_;
    return unless $fqdn_host;
    
    my $host = $1 if ($fqdn_host =~ /^(\w+)\.(\w+)\.(\w+)$/);
    
    if ($host) {
        $dbh->do(<< "SQL_STATEMENT");
-- convert host name to fqdn if not done already
LOCK TABLE prd_pmx_host IN EXCLUSIVE MODE;
UPDATE prd_pmx_host
SET name = '$fqdn_host' where name = '$host'
;
SQL_STATEMENT
    
        $dbh->commit() or 
            die "Failed to UPDATE host name in prd_pmx_host: $dbh->errstr()";
    }
}

sub _save_hostname {
    my ($dbh, $hostname) = @_;

    $dbh->do(<< "SQL_STATEMENT");
-- populate prd_pmx_host
LOCK TABLE prd_pmx_host IN EXCLUSIVE MODE;
INSERT INTO prd_pmx_host (name)
SELECT '$hostname'::text
WHERE '$hostname' NOT IN
(
 SELECT name FROM prd_pmx_host
)
;
SQL_STATEMENT

    $dbh->commit() or
        die "Failed to INSERT host name in prd_pmx_host: $dbh->errstr()";
}

1;
